get_activity

Function get_activity 

pub async fn get_activity(
    user: &'_ str,
    date_range: (NaiveDate, NaiveDate),
    maybe_token: Option<String>,
) -> Result<Activity, Box<dyn Error>>
Function using GitHub GraphQL API to download target user activity on the specified date range. if maybe_tokenis not None, it will be used as application authentication token. This is required to obtain private repositories contributions.