pub struct Activity {
pub date_range: (NaiveDate, NaiveDate),
pub contributions: HashMap<YearWeek, HashMap<Weekday, u32>>,
}Expand description
Data structure representing the GitHub user activity
Fields
date_range: (NaiveDate, NaiveDate)Date range of the represented activity period
contributions: HashMap<YearWeek, HashMap<Weekday, u32>>Contributions in the activity date range, it is a map from year to weeks. Weeks are represented as a map from the day of the way (e.g: 0 -> Monday) to the number of contributions on that day.
Implementations